@@ -365,7 +365,9 @@ def test_asset_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options)
@@ -431,7 +433,8 @@ def test_search_all_resources(
     transport: str = "grpc", request_type=asset_service.SearchAllResourcesRequest
 ):
     client = AssetServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -472,7 +475,8 @@ async def test_search_all_resources_async(
     request_type=asset_service.SearchAllResourcesRequest,
 ):
     client = AssetServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -510,7 +514,9 @@ async def test_search_all_resources_async_from_dict():
 
 
 def test_search_all_resources_field_headers():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -532,12 +538,17 @@ def test_search_all_resources_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "scope=scope/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "scope=scope/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
 async def test_search_all_resources_field_headers_async():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -561,11 +572,16 @@ async def test_search_all_resources_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "scope=scope/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "scope=scope/value",
+    ) in kw["metadata"]
 
 
 def test_search_all_resources_flattened():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -577,7 +593,9 @@ def test_search_all_resources_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.search_all_resources(
-            scope="scope_value", query="query_value", asset_types=["asset_types_value"],
+            scope="scope_value",
+            query="query_value",
+            asset_types=["asset_types_value"],
         )
 
         # Establish that the underlying call was made with the expected
@@ -593,7 +611,9 @@ def test_search_all_resources_flattened():
 
 
 def test_search_all_resources_flattened_error():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -608,7 +628,9 @@ def test_search_all_resources_flattened_error():
 
 @pytest.mark.asyncio
 async def test_search_all_resources_flattened_async():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -623,7 +645,9 @@ async def test_search_all_resources_flattened_async():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         response = await client.search_all_resources(
-            scope="scope_value", query="query_value", asset_types=["asset_types_value"],
+            scope="scope_value",
+            query="query_value",
+            asset_types=["asset_types_value"],
         )
 
         # Establish that the underlying call was made with the expected
@@ -640,7 +664,9 @@ async def test_search_all_resources_flattened_async():
 
 @pytest.mark.asyncio
 async def test_search_all_resources_flattened_error_async():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -654,7 +680,9 @@ async def test_search_all_resources_flattened_error_async():
 
 
 def test_search_all_resources_pager():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials,)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -671,10 +699,14 @@ def test_search_all_resources_pager():
                 next_page_token="abc",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[assets.StandardResourceMetadata(),], next_page_token="ghi",
+                results=[
+                    assets.StandardResourceMetadata(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllResourcesResponse(
                 results=[
@@ -699,7 +731,9 @@ def test_search_all_resources_pager():
 
 
 def test_search_all_resources_pages():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials,)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -716,10 +750,14 @@ def test_search_all_resources_pages():
                 next_page_token="abc",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[assets.StandardResourceMetadata(),], next_page_token="ghi",
+                results=[
+                    assets.StandardResourceMetadata(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllResourcesResponse(
                 results=[
@@ -736,7 +774,9 @@ def test_search_all_resources_pages():
 
 @pytest.mark.asyncio
 async def test_search_all_resources_async_pager():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials,)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -755,10 +795,14 @@ async def test_search_all_resources_async_pager():
                 next_page_token="abc",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[assets.StandardResourceMetadata(),], next_page_token="ghi",
+                results=[
+                    assets.StandardResourceMetadata(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllResourcesResponse(
                 results=[
@@ -768,7 +812,9 @@ async def test_search_all_resources_async_pager():
             ),
             RuntimeError,
         )
-        async_pager = await client.search_all_resources(request={},)
+        async_pager = await client.search_all_resources(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
         async for response in async_pager:
@@ -780,7 +826,9 @@ async def test_search_all_resources_async_pager():
 
 @pytest.mark.asyncio
 async def test_search_all_resources_async_pages():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials,)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -799,10 +847,14 @@ async def test_search_all_resources_async_pages():
                 next_page_token="abc",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[assets.StandardResourceMetadata(),], next_page_token="ghi",
+                results=[
+                    assets.StandardResourceMetadata(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllResourcesResponse(
                 results=[
@@ -823,7 +875,8 @@ def test_search_all_iam_policies(
     transport: str = "grpc", request_type=asset_service.SearchAllIamPoliciesRequest
 ):
     client = AssetServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -864,7 +917,8 @@ async def test_search_all_iam_policies_async(
     request_type=asset_service.SearchAllIamPoliciesRequest,
 ):
     client = AssetServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -902,7 +956,9 @@ async def test_search_all_iam_policies_async_from_dict():
 
 
 def test_search_all_iam_policies_field_headers():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -924,12 +980,17 @@ def test_search_all_iam_policies_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "scope=scope/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "scope=scope/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
 async def test_search_all_iam_policies_field_headers_async():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -953,11 +1014,16 @@ async def test_search_all_iam_policies_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "scope=scope/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "scope=scope/value",
+    ) in kw["metadata"]
 
 
 def test_search_all_iam_policies_flattened():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -969,7 +1035,8 @@ def test_search_all_iam_policies_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.search_all_iam_policies(
-            scope="scope_value", query="query_value",
+            scope="scope_value",
+            query="query_value",
         )
 
         # Establish that the underlying call was made with the expected
@@ -983,7 +1050,9 @@ def test_search_all_iam_policies_flattened():
 
 
 def test_search_all_iam_policies_flattened_error():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -997,7 +1066,9 @@ def test_search_all_iam_policies_flattened_error():
 
 @pytest.mark.asyncio
 async def test_search_all_iam_policies_flattened_async():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1012,7 +1083,8 @@ async def test_search_all_iam_policies_flattened_async():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         response = await client.search_all_iam_policies(
-            scope="scope_value", query="query_value",
+            scope="scope_value",
+            query="query_value",
         )
 
         # Establish that the underlying call was made with the expected
@@ -1027,7 +1099,9 @@ async def test_search_all_iam_policies_flattened_async():
 
 @pytest.mark.asyncio
 async def test_search_all_iam_policies_flattened_error_async():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1040,7 +1114,9 @@ async def test_search_all_iam_policies_flattened_error_async():
 
 
 def test_search_all_iam_policies_pager():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials,)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1057,10 +1133,14 @@ def test_search_all_iam_policies_pager():
                 next_page_token="abc",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[assets.IamPolicySearchResult(),], next_page_token="ghi",
+                results=[
+                    assets.IamPolicySearchResult(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllIamPoliciesResponse(
                 results=[
@@ -1085,7 +1165,9 @@ def test_search_all_iam_policies_pager():
 
 
 def test_search_all_iam_policies_pages():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials,)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1102,10 +1184,14 @@ def test_search_all_iam_policies_pages():
                 next_page_token="abc",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[assets.IamPolicySearchResult(),], next_page_token="ghi",
+                results=[
+                    assets.IamPolicySearchResult(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllIamPoliciesResponse(
                 results=[
@@ -1122,7 +1208,9 @@ def test_search_all_iam_policies_pages():
 
 @pytest.mark.asyncio
 async def test_search_all_iam_policies_async_pager():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials,)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1141,10 +1229,14 @@ async def test_search_all_iam_policies_async_pager():
                 next_page_token="abc",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[assets.IamPolicySearchResult(),], next_page_token="ghi",
+                results=[
+                    assets.IamPolicySearchResult(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllIamPoliciesResponse(
                 results=[
@@ -1154,7 +1246,9 @@ async def test_search_all_iam_policies_async_pager():
             ),
             RuntimeError,
         )
-        async_pager = await client.search_all_iam_policies(request={},)
+        async_pager = await client.search_all_iam_policies(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
         async for response in async_pager:
@@ -1166,7 +1260,9 @@ async def test_search_all_iam_policies_async_pager():
 
 @pytest.mark.asyncio
 async def test_search_all_iam_policies_async_pages():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials,)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1185,10 +1281,14 @@ async def test_search_all_iam_policies_async_pages():
                 next_page_token="abc",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[assets.IamPolicySearchResult(),], next_page_token="ghi",
+                results=[
+                    assets.IamPolicySearchResult(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllIamPoliciesResponse(
                 results=[
@@ -1212,7 +1312,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AssetServiceClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1231,7 +1332,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AssetServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1273,8 +1375,13 @@ def test_transport_adc(transport_class):
 
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.AssetServiceGrpcTransport,)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.AssetServiceGrpcTransport,
+    )
 
 
 def test_asset_service_base_transport_error():
@@ -1317,7 +1424,8 @@ def test_asset_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (credentials.AnonymousCredentials(), None)
         transport = transports.AssetServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1387,7 +1495,8 @@ def test_asset_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AssetServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1399,7 +1508,8 @@ def test_asset_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AssetServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1510,7 +1620,9 @@ def test_parse_common_billing_account_path():
 def test_common_folder_path():
     folder = "whelk"
 
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = AssetServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1529,7 +1641,9 @@ def test_parse_common_folder_path():
 def test_common_organization_path():
     organization = "oyster"
 
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = AssetServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1548,7 +1662,9 @@ def test_parse_common_organization_path():
 def test_common_project_path():
     project = "cuttlefish"
 
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = AssetServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1569,7 +1685,8 @@ def test_common_location_path():
     location = "nautilus"
 
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = AssetServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1594,7 +1711,8 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.AssetServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = AssetServiceClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1603,6 +1721,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = AssetServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
