@@ -366,7 +366,9 @@ def test_asset_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options)
@@ -432,7 +434,8 @@ def test_list_assets(
     transport: str = "grpc", request_type=asset_service.ListAssetsRequest
 ):
     client = AssetServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -470,7 +473,8 @@ async def test_list_assets_async(
     transport: str = "grpc_asyncio", request_type=asset_service.ListAssetsRequest
 ):
     client = AssetServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -481,7 +485,9 @@ async def test_list_assets_async(
     with mock.patch.object(type(client.transport.list_assets), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            asset_service.ListAssetsResponse(next_page_token="next_page_token_value",)
+            asset_service.ListAssetsResponse(
+                next_page_token="next_page_token_value",
+            )
         )
 
         response = await client.list_assets(request)
@@ -504,7 +510,9 @@ async def test_list_assets_async_from_dict():
 
 
 def test_list_assets_field_headers():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -524,12 +532,17 @@ def test_list_assets_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
 async def test_list_assets_field_headers_async():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -551,25 +564,45 @@ async def test_list_assets_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 def test_list_assets_pager():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials,)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_assets), "__call__") as call:
         # Set the response to a series of pages.
         call.side_effect = (
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(), assets.Asset(), assets.Asset(),],
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
                 next_page_token="abc",
             ),
-            asset_service.ListAssetsResponse(assets=[], next_page_token="def",),
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(),], next_page_token="ghi",
+                assets=[],
+                next_page_token="def",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                ],
+                next_page_token="ghi",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
             ),
-            asset_service.ListAssetsResponse(assets=[assets.Asset(), assets.Asset(),],),
             RuntimeError,
         )
 
@@ -587,21 +620,38 @@ def test_list_assets_pager():
 
 
 def test_list_assets_pages():
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials,)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_assets), "__call__") as call:
         # Set the response to a series of pages.
         call.side_effect = (
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(), assets.Asset(), assets.Asset(),],
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
                 next_page_token="abc",
             ),
-            asset_service.ListAssetsResponse(assets=[], next_page_token="def",),
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(),], next_page_token="ghi",
+                assets=[],
+                next_page_token="def",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                ],
+                next_page_token="ghi",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
             ),
-            asset_service.ListAssetsResponse(assets=[assets.Asset(), assets.Asset(),],),
             RuntimeError,
         )
         pages = list(client.list_assets(request={}).pages)
@@ -611,7 +661,9 @@ def test_list_assets_pages():
 
 @pytest.mark.asyncio
 async def test_list_assets_async_pager():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials,)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -620,17 +672,34 @@ async def test_list_assets_async_pager():
         # Set the response to a series of pages.
         call.side_effect = (
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(), assets.Asset(), assets.Asset(),],
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
                 next_page_token="abc",
             ),
-            asset_service.ListAssetsResponse(assets=[], next_page_token="def",),
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(),], next_page_token="ghi",
+                assets=[],
+                next_page_token="def",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                ],
+                next_page_token="ghi",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
             ),
-            asset_service.ListAssetsResponse(assets=[assets.Asset(), assets.Asset(),],),
             RuntimeError,
         )
-        async_pager = await client.list_assets(request={},)
+        async_pager = await client.list_assets(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
         async for response in async_pager:
@@ -642,7 +711,9 @@ async def test_list_assets_async_pager():
 
 @pytest.mark.asyncio
 async def test_list_assets_async_pages():
-    client = AssetServiceAsyncClient(credentials=credentials.AnonymousCredentials,)
+    client = AssetServiceAsyncClient(
+        credentials=credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -651,14 +722,29 @@ async def test_list_assets_async_pages():
         # Set the response to a series of pages.
         call.side_effect = (
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(), assets.Asset(), assets.Asset(),],
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
                 next_page_token="abc",
             ),
-            asset_service.ListAssetsResponse(assets=[], next_page_token="def",),
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(),], next_page_token="ghi",
+                assets=[],
+                next_page_token="def",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                ],
+                next_page_token="ghi",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
             ),
-            asset_service.ListAssetsResponse(assets=[assets.Asset(), assets.Asset(),],),
             RuntimeError,
         )
         pages = []
@@ -675,7 +761,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AssetServiceClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -694,7 +781,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AssetServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -736,8 +824,13 @@ def test_transport_adc(transport_class):
 
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = AssetServiceClient(credentials=credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.AssetServiceGrpcTransport,)
+    client = AssetServiceClient(
+        credentials=credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.AssetServiceGrpcTransport,
+    )
 
 
 def test_asset_service_base_transport_error():
@@ -777,7 +870,8 @@ def test_asset_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (credentials.AnonymousCredentials(), None)
         transport = transports.AssetServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -847,7 +941,8 @@ def test_asset_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AssetServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -859,7 +954,8 @@ def test_asset_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AssetServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -977,7 +1073,9 @@ def test_parse_common_billing_account_path():
 def test_common_folder_path():
     folder = "whelk"
 
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = AssetServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -996,7 +1094,9 @@ def test_parse_common_folder_path():
 def test_common_organization_path():
     organization = "oyster"
 
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = AssetServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1015,7 +1115,9 @@ def test_parse_common_organization_path():
 def test_common_project_path():
     project = "cuttlefish"
 
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = AssetServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1036,7 +1138,8 @@ def test_common_location_path():
     location = "nautilus"
 
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = AssetServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1061,7 +1164,8 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.AssetServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = AssetServiceClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1070,6 +1174,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = AssetServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
